@@ -1,7 +1,9 @@
 import datetime
+import gettext
 import json
+import sys
 import time
-from typing import Any, ClassVar, Dict, List, Optional, Tuple, Type
+from typing import IO, Any, ClassVar, Dict, List, Optional, Tuple, Type, Union
 
 import click
 import yaml
@@ -20,6 +22,7 @@ else:
     PYGMENTS = True
     PYGMENTS_STYLE = "solarized-dark"
 
+_ = gettext.gettext
 
 DEFAULT_LIMIT = 25
 BATCH_SIZE = 25
@@ -29,6 +32,28 @@ EntityDefinition = Dict[str, Any]
 RepositoryDefinition = Tuple[str, str]  # name, pulp_type
 RepositoryVersionDefinition = Tuple[str, str, int]  # name, pulp_type, version
 
+new_component_names_to_pre_3_11_names: Dict[str, str] = dict(
+    ansible="pulp_ansible",
+    container="pulp_container",
+    core="pulpcore",
+    deb="pulp_deb",
+    file="pulp_file",
+    rpm="pulp_rpm",
+)
+
+
+class PulpNoWait(click.ClickException):
+    exit_code = 0
+
+    def show(self, file: Optional[IO[str]] = None) -> None:
+        """
+        Format the message into file or STDERR.
+        Overwritten from base class to not print "Error: ".
+        """
+        if file is None:
+            file = click.get_text_stream("stderr")
+        click.echo(self.format_message(), file=file)
+
 
 class PulpJSONEncoder(json.JSONEncoder):
     def default(self, obj: Any) -> Any:
@@ -48,6 +73,7 @@ class PulpContext:
         self._api: Optional[OpenAPI] = None
         self._api_kwargs = api_kwargs
         self._needed_plugins: List[Tuple[str, Optional[str], Optional[str]]] = []
+        self.isatty: bool = sys.stdout.isatty()
 
         self.format: str = format
         self.background_tasks: bool = background_tasks
@@ -76,13 +102,13 @@ class PulpContext:
         Dump the provided result to the console using the selected renderer
         """
         if self.format == "json":
-            output = json.dumps(result, cls=PulpJSONEncoder, indent=2)
-            if PYGMENTS:
+            output = json.dumps(result, cls=PulpJSONEncoder, indent=(2 if self.isatty else None))
+            if PYGMENTS and self.isatty:
                 output = highlight(output, JsonLexer(), Terminal256Formatter(style=PYGMENTS_STYLE))
             click.echo(output)
         elif self.format == "yaml":
             output = yaml.dump(result)
-            if PYGMENTS:
+            if PYGMENTS and self.isatty:
                 output = highlight(output, YamlLexer(), Terminal256Formatter(style=PYGMENTS_STYLE))
             click.echo(output)
         elif self.format == "none":
@@ -90,10 +116,12 @@ class PulpContext:
         else:
             raise NotImplementedError(f"Format '{self.format}' not implemented.")
 
-    def call(self, operation_id: str, *args: Any, **kwargs: Any) -> Any:
+    def call(self, operation_id: str, non_blocking: bool = False, *args: Any, **kwargs: Any) -> Any:
         """
         Perform an API call for operation_id.
         Wait for triggered tasks to finish if not background.
+        Returns the operation result, or the finished task.
+        If non_blocking, returns unfinished tasks.
         """
         try:
             result = self.api.call(operation_id, *args, **kwargs)
@@ -105,14 +133,17 @@ class PulpContext:
             task_href = result["task"]
             result = self.api.call("tasks_read", parameters={"task_href": task_href})
             click.echo(f"Started background task {task_href}", err=True)
-            if not self.background_tasks:
+            if not non_blocking:
                 result = self.wait_for_task(result)
         return result
 
     def wait_for_task(self, task: EntityDefinition, timeout: int = 120) -> Any:
         """
         Wait for a task to finish and return the finished task object.
+        Raise `click.ClickException` on timeout, background, ctrl-c, if task failed or was canceled.
         """
+        if self.background_tasks:
+            raise PulpNoWait("Not waiting for task because --background was specified.")
         task_href = task["pulp_href"]
         try:
             while True:
@@ -136,8 +167,7 @@ class PulpContext:
                     raise NotImplementedError(f"Unknown task state: {task['state']}")
             raise click.ClickException("Task timed out")
         except KeyboardInterrupt:
-            click.echo(f"Task {task_href} sent to background.", err=True)
-            return task
+            raise PulpNoWait(f"Task {task_href} sent to background.")
 
     def has_plugin(
         self, name: str, min_version: Optional[str] = None, max_version: Optional[str] = None
@@ -148,7 +178,10 @@ class PulpContext:
             return (min_version is None) and (max_version is None)
         version: Optional[str] = self.component_versions.get(name)
         if version is None:
-            return False
+            pre_3_11_name: str = new_component_names_to_pre_3_11_names.get(name, "")
+            version = self.component_versions.get(pre_3_11_name)
+            if version is None:
+                return False
         if min_version is not None:
             if parse_version(version) < parse_version(min_version):
                 return False
@@ -268,6 +301,7 @@ class PulpEntityContext:
     ) -> None:
         assert pulp_href is None or entity is None
 
+        self.meta: Dict[str, str] = {}
         self.pulp_ctx: PulpContext = pulp_ctx
         self._entity = None
         if pulp_href is None:
@@ -275,6 +309,13 @@ class PulpEntityContext:
         else:
             self.pulp_href = pulp_href
 
+    def preprocess_body(self, body: EntityDefinition) -> EntityDefinition:
+        return {
+            key: value.pulp_href if isinstance(value, PulpEntityContext) else value
+            for key, value in body.items()
+            if value is not None
+        }
+
     def list(self, limit: int, offset: int, parameters: Dict[str, Any]) -> List[Any]:
         count: int = -1
         entities: List[Any] = []
@@ -307,11 +348,21 @@ class PulpEntityContext:
     def show(self, href: str) -> Any:
         return self.pulp_ctx.call(self.READ_ID, parameters={self.HREF: href})
 
-    def create(self, body: EntityDefinition, parameters: Optional[Dict[str, Any]] = None) -> Any:
+    def create(
+        self,
+        body: EntityDefinition,
+        parameters: Optional[Dict[str, Any]] = None,
+        non_blocking: bool = False,
+    ) -> Any:
         _parameters = self.scope
         if parameters:
             _parameters.update(parameters)
-        return self.pulp_ctx.call(self.CREATE_ID, parameters=_parameters, body=body)
+        result = self.pulp_ctx.call(
+            self.CREATE_ID, parameters=_parameters, body=body, non_blocking=non_blocking
+        )
+        if not non_blocking and result["pulp_href"].startswith("/pulp/api/v3/tasks/"):
+            result = self.show(result["created_resources"][0])
+        return result
 
     def update(
         self,
@@ -319,26 +370,33 @@ class PulpEntityContext:
         body: EntityDefinition,
         parameters: Optional[Dict[str, Any]] = None,
         uploads: Optional[Dict[str, Any]] = None,
+        non_blocking: bool = False,
     ) -> Any:
         _parameters = {self.HREF: href}
         if parameters:
             _parameters.update(parameters)
         return self.pulp_ctx.call(
-            self.UPDATE_ID, parameters=_parameters, body=body, uploads=uploads
+            self.UPDATE_ID,
+            parameters=_parameters,
+            body=body,
+            uploads=uploads,
+            non_blocking=non_blocking,
         )
 
-    def delete(self, href: str) -> Any:
-        return self.pulp_ctx.call(self.DELETE_ID, parameters={self.HREF: href})
+    def delete(self, href: str, non_blocking: bool = False) -> Any:
+        return self.pulp_ctx.call(
+            self.DELETE_ID, parameters={self.HREF: href}, non_blocking=non_blocking
+        )
 
-    def set_label(self, href: str, key: str, value: str) -> Any:
+    def set_label(self, href: str, key: str, value: str, non_blocking: bool = False) -> Any:
         entity = self.show(href)
         entity["pulp_labels"][key] = value
-        return self.update(href, body=entity)
+        return self.update(href, body=entity, non_blocking=non_blocking)
 
-    def unset_label(self, href: str, key: str) -> Any:
+    def unset_label(self, href: str, key: str, non_blocking: bool = False) -> Any:
         entity = self.show(href)
         entity["pulp_labels"].pop(key)
-        return self.update(href, body=entity)
+        return self.update(href, body=entity, non_blocking=non_blocking)
 
     def show_label(self, href: str, key: str) -> Any:
         entity = self.show(href)
@@ -458,6 +516,7 @@ class PulpRepositoryContext(PulpEntityContext):
         )
 
 
+EntityFieldDefinition = Union[None, str, PulpEntityContext]
 ##############################################################################
 # Decorator to access certain contexts
 
