@@ -1,9 +1,12 @@
+import gettext
 import sys
 
 import click
 
 from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 
+_ = gettext.gettext
+
 
 @click.group()
 def debug() -> None:
