@@ -1,3 +1,4 @@
+import gettext
 from copy import deepcopy
 from typing import IO
 
@@ -7,6 +8,8 @@ from pulpcore.cli.common.context import PulpContext, pass_entity_context, pass_p
 from pulpcore.cli.common.generic import list_entities, show_by_href
 from pulpcore.cli.core.context import PulpArtifactContext
 
+_ = gettext.gettext
+
 
 @click.group()
 @pass_pulp_context
@@ -26,7 +29,7 @@ artifact.add_command(show_by_href)
 @artifact.command()
 @click.option("--file", type=click.File("rb"), required=True)
 @click.option(
-    "--chunk-size", default=1000000, type=int, help="Chunk size in bytes (default is 1 MB)"
+    "--chunk-size", default=1000000, type=int, help=_("Chunk size in bytes (default is 1 MB)")
 )
 @pass_entity_context
 @pass_pulp_context
