@@ -1,7 +1,11 @@
+import gettext
+
 import click
 
 from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 
+_ = gettext.gettext
+
 
 @click.group()
 def orphans() -> None:
