@@ -1,3 +1,5 @@
+import gettext
+
 from pulpcore.cli.common import main
 from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 from pulpcore.cli.file.content import content
@@ -6,11 +8,13 @@ from pulpcore.cli.file.publication import publication
 from pulpcore.cli.file.remote import remote
 from pulpcore.cli.file.repository import repository
 
+_ = gettext.gettext
+
 
 @main.group(name="file")
 @pass_pulp_context
 def file_group(pulp_ctx: PulpContext) -> None:
-    pulp_ctx.needs_plugin("pulp_file")
+    pulp_ctx.needs_plugin("file")
 
 
 file_group.add_command(repository)
