@@ -1,22 +1,26 @@
-import json
-from typing import Any, Dict, List, Optional, Union
+import gettext
+from typing import Dict, List, Optional, Union
 
 import click
 
 from pulpcore.cli.common.context import (
     PulpContext,
+    PulpEntityContext,
     PulpRepositoryContext,
     pass_pulp_context,
     pass_repository_context,
 )
 from pulpcore.cli.common.generic import (
+    create_command,
     destroy_command,
     href_option,
     label_command,
     label_select_option,
     list_command,
+    load_json_callback,
     name_option,
     show_command,
+    update_command,
     version_command,
 )
 from pulpcore.cli.file.context import (
@@ -25,6 +29,18 @@ from pulpcore.cli.file.context import (
     PulpFileRepositoryContext,
 )
 
+_ = gettext.gettext
+
+
+def _remote_callback(
+    ctx: click.Context, param: click.Parameter, value: Optional[str]
+) -> Optional[Union[str, PulpEntityContext]]:
+    # Pass None and "" verbatim
+    if value:
+        pulp_ctx: PulpContext = ctx.find_object(PulpContext)
+        return PulpFileRemoteContext(pulp_ctx, entity={"name": value})
+    return value
+
 
 @click.group()
 @click.option(
@@ -44,89 +60,41 @@ def repository(ctx: click.Context, pulp_ctx: PulpContext, repo_type: str) -> Non
 
 
 lookup_options = [href_option, name_option]
+create_options = [
+    click.option("--name", required=True),
+    click.option("--description"),
+    click.option("--remote", callback=_remote_callback),
+]
+update_options = [
+    click.option("--description"),
+    click.option("--remote", callback=_remote_callback),
+]
 
 repository.add_command(list_command(decorators=[label_select_option]))
 repository.add_command(show_command(decorators=lookup_options))
+repository.add_command(create_command(decorators=create_options))
+repository.add_command(update_command(decorators=lookup_options + update_options))
 repository.add_command(destroy_command(decorators=lookup_options))
 repository.add_command(version_command())
 repository.add_command(label_command())
 
 
-@repository.command()
-@click.option("--name", required=True)
-@click.option("--description")
-@click.option("--remote")
-@pass_repository_context
-@pass_pulp_context
-def create(
-    pulp_ctx: PulpContext,
-    repository_ctx: PulpRepositoryContext,
-    name: str,
-    description: Optional[str],
-    remote: Optional[str],
-) -> None:
-    repository = {"name": name, "description": description}
-    if remote:
-        remote_href: str = PulpFileRemoteContext(pulp_ctx, entity={"name": remote}).pulp_href
-        repository["remote"] = remote_href
-
-    result = repository_ctx.create(body=repository)
-    pulp_ctx.output_result(result)
-
-
 @repository.command()
 @name_option
 @href_option
-@click.option("--description")
-@click.option("--remote")
+@click.option("--remote", callback=_remote_callback)
 @pass_repository_context
-@pass_pulp_context
-def update(
-    pulp_ctx: PulpContext,
-    repository_ctx: PulpRepositoryContext,
-    description: Optional[str],
-    remote: Optional[str],
-) -> None:
-    repository = repository_ctx.entity
-    repository_href = repository_ctx.pulp_href
-
-    if description is not None:
-        if description == "":
-            # unset the description
-            description = None
-        if description != repository["description"]:
-            repository["description"] = description
-
-    if remote is not None:
-        if remote == "":
-            # unset the remote
-            repository["remote"] = ""
-        elif remote:
-            remote_href: str = PulpFileRemoteContext(pulp_ctx, entity={"name": remote}).pulp_href
-            repository["remote"] = remote_href
-
-    repository_ctx.update(repository_href, body=repository)
-
-
-@repository.command()
-@name_option
-@href_option
-@click.option("--remote")
-@pass_repository_context
-@pass_pulp_context
 def sync(
-    pulp_ctx: PulpContext,
     repository_ctx: PulpRepositoryContext,
-    remote: Optional[str],
+    remote: Optional[Union[str, PulpEntityContext]],
 ) -> None:
     repository = repository_ctx.entity
     repository_href = repository_ctx.pulp_href
 
     body = {}
 
-    if remote:
-        remote_href: str = PulpFileRemoteContext(pulp_ctx).find(name=remote)["pulp_href"]
-        body["remote"] = remote_href
+    if isinstance(remote, PulpEntityContext):
+        body["remote"] = remote.pulp_href
     elif repository["remote"] is None:
         name = repository["name"]
         raise click.ClickException(
@@ -207,33 +175,6 @@ def remove(
     )
 
 
-def _load_json_from_option(
-    ctx: click.Context,
-    option_name: Any,
-    option_value: str,
-) -> List[Dict[str, str]]:
-    """Load JSON from input string or from file if string starts with @."""
-    json_object: List[Dict[str, str]]
-    json_string: Union[str, bytes]
-
-    if option_value.startswith("@"):
-        json_file = option_value[1:]
-        try:
-            with click.open_file(json_file, "rb") as fp:
-                json_string = fp.read()
-        except OSError:
-            raise click.ClickException(f"Failed to load content from {json_file}")
-    else:
-        json_string = option_value
-
-    try:
-        json_object = json.loads(json_string)
-    except json.decoder.JSONDecodeError:
-        raise click.ClickException("Failed to decode JSON")
-    else:
-        return json_object
-
-
 @repository.command()
 @name_option
 @href_option
@@ -241,22 +182,24 @@ def _load_json_from_option(
 @click.option(
     "--add-content",
     default="[]",
-    callback=_load_json_from_option,
-    is_eager=True,
+    callback=load_json_callback,
     expose_value=True,
-    help="""JSON string with a list of objects to add to the repository.
+    help=_(
+        """JSON string with a list of objects to add to the repository.
     Each object should consist of the following keys: "sha256", "relative_path"..
-    The argument prefixed with the '@' can be the path to a JSON file with a list of objects.""",
+    The argument prefixed with the '@' can be the path to a JSON file with a list of objects."""
+    ),
 )
 @click.option(
     "--remove-content",
     default="[]",
-    callback=_load_json_from_option,
-    is_eager=True,
+    callback=load_json_callback,
     expose_value=True,
-    help="""JSON string with a list of objects to remove from the repository.
+    help=_(
+        """JSON string with a list of objects to remove from the repository.
     Each object should consist of the following keys: "sha256", "relative_path"..
-    The argument prefixed with the '@' can be the path to a JSON file with a list of objects.""",
+    The argument prefixed with the '@' can be the path to a JSON file with a list of objects."""
+    ),
 )
 @pass_repository_context
 @pass_pulp_context
